@@ -146,8 +146,8 @@ def Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float,
         raise KineticlibError('Types of molecules do not match!')
 
 
-def Gamma_diss(T: float, T1: float, atom1: Atom, atom2: Atom, molecule: MoleculeQuasi, n_molecule: float, n_atom1: float,
-               n_atom2: float, diss_level: int) -> float:
+def Gamma_diss(T: float, T1: float, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom, n_molecule: float,
+               n_atom1: float, n_atom2: float, diss_level: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{diss}` for a dissociation reaction:
     **AB(diss_level) + P -> A + B + P** in the multi and one-temperature approximations
 
