@@ -165,8 +165,12 @@ def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecu
     float
         The dissociation crosssection
     """
-    return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss_offset, center_of_mass,
-                                              vl_dependent)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
+                                                  center_of_mass, vl_dependent)
+    else:
+        return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss,
+                                                  center_of_mass, vl_dependent)
 
 
 def min_dimensionless_vel_diss(T: float, molecule: Molecule, i: int, vl_dependent: bool=True) -> float:
@@ -192,7 +196,11 @@ def min_dimensionless_vel_diss(T: float, molecule: Molecule, i: int, vl_dependen
         The minimum value of the dimensionless relative velocity
 
     """
-    return raw_min_dimensionless_vel_diss(T, molecule.vibr[i], molecule.diss_offset, vl_dependent)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_min_dimensionless_vel_diss(T, molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
+                                              vl_dependent)
+    else:
+        return raw_min_dimensionless_vel_diss(T, molecule.vibr[i], molecule.diss, vl_dependent)
 
 
 def vt_integral_fho(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i: int, delta: int,
@@ -322,8 +330,12 @@ def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule:
     float
         The generalized omega integral over the dissociation crosssection
     """
-    return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
-                                          center_of_mass, vl_dependent, nokt)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i] + molecule.vibr_zero,
+                                              molecule.diss, center_of_mass, vl_dependent, nokt)
+    else:
+        return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i],
+                                              molecule.diss, center_of_mass, vl_dependent, nokt)
 
 
 def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=False, nokt: bool=False) -> float:
@@ -646,7 +658,7 @@ def raw_crosssection_vt_fho(g: float, T: float, sigma: float, mass: float, beta:
     molecule_vibr_zero : float
         the energy of the 0-th vibrational level
     molecule_diss : float
-        the dissociation energy of the molecule which undergoes the transition
+        the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
         the vibrational level of the molecule
     delta : int
@@ -737,9 +749,9 @@ def raw_crosssection_diss_rigid_sphere(g: float, T: float, sigma: float, molecul
         the collision diameter :math:`\\sigma_{cd}`
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value)
+        is ``False``, can be any value) (with no offset)
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     center_of_mass : bool, optional
         if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
         if ``False``, the total kinetic energy will be used, defaults to ``True``
@@ -777,9 +789,9 @@ def raw_min_dimensionless_vel_diss(T: float, molecule_vibr: float, molecule_diss
         the temperature of the mixture
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value)
+        is ``False``, can be any value) (with no offset)
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     vl_dependent : bool, optional
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the dissociating
         molecule, if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
@@ -863,7 +875,7 @@ def raw_vt_integral_fho(T: float, deg: int, mass: float, beta: float, vssc: floa
     molecule_vibr_zero : float
         the energy of the 0-th vibrational level
     molecule_diss : float
-        the dissociation energy of the molecule which undergoes the transition
+        the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
         the vibrational level of the molecule
     delta : int
@@ -932,7 +944,7 @@ def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
     molecule_vibr_zero : float
         the energy of the 0-th vibrational level
     molecule_diss : float
-        the dissociation energy of the molecule which undergoes the transition
+        the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
         the vibrational level of the molecule
     delta : int
@@ -1122,9 +1134,9 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float
         the collision-reduced mass :math:`m_{cd}`
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value)
+        is ``False``, can be any value) (with no offset)
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     center_of_mass : bool, optional
         if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
         if ``False``, the total kinetic energy will be used, defaults to ``True``
