@@ -121,7 +121,7 @@ class Atom(Particle):
 
 class Molecule(Particle):
     """Molecule class for a state-to-state approximation
-    Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
+    Provides various methods such as averaged rotational energies, rotational exponents,
     dissociation-related partition functions, etc.
 
     Attributes
@@ -174,8 +174,7 @@ class Molecule(Particle):
     -----
     Attributes whose names begin with `_current_` are not meant to be accessed directly, as doing so may lead to errors,
     they are calculated when the `renorm_sts` method is called, and are correct only if the current flow temperature
-    is the same as the temperature which was passed to the `renorm_sts` method
-    The energy of the 0th vibrational level is set to 0, the non-zero value is stored in the vibr_zero field
+    is the same as the temperature which was passed to the `renorm_sts` method.
     """
     def __init__(self, name: str, vmodel: str='anharmonic'):
         """Creates a new molecule
@@ -504,14 +503,7 @@ class Molecule(Particle):
 class MoleculeQuasi(Molecule):
     """Molecule class for quasi-stationary approximations
     Used for type annotations, adds some internal things compared to the Molecule class, but other than that,
-    is full identical
-
-    Notes
-    -----
-    Attributes whose names begin with `_current_` are not meant to be accessed directly, as doing so may lead to errors,
-    they are calculated when the `renorm_sts` method is called, and are correct only if the current flow temperature
-    is the same as the temperature which was passed to the `renorm_sts` method
-    The energy of the 0th vibrational level is set to 0, the non-zero value is stored in the vibr_zero field
+    is fully identical.
     """
     def __init__(self, name, vmodel='anharmonic'):
         """Creates a new molecule
@@ -548,8 +540,8 @@ class MoleculeQuasi(Molecule):
 
 class MoleculeMultiT(MoleculeQuasi):
     """Molecule class for a multi-temperature approximation
-    Builds upon the MoleculeSTS class, and provides additional methods concerning vibrational partition functions,
-    their derivatives, etc.
+    Provides additional methods (compared to ``Molecule``) such as averaged vibrational energies, vibrational exponents,
+    etc.
 
     Attributes
     ----------
@@ -559,7 +551,8 @@ class MoleculeMultiT(MoleculeQuasi):
     -----
     Attributes whose names begin with `_current_` are not meant to be accessed directly, as doing so may lead to errors,
     they are calculated when the `renorm` method is called, and are correct only if the current flow temperature
-    is the same as the temperature which was passed to the `renorm` method
+    is the same as the temperature which was passed to the `renorm` method.
+
     The energy of the 0th vibrational level is set to 0, the non-zero value is stored in the vibr_zero field
     """
     def __init__(self, name, vmodel='anharmonic'):
@@ -1099,9 +1092,9 @@ class MoleculeMultiT(MoleculeQuasi):
 
 
 class MoleculeOneT(MoleculeQuasi):
-    """Molecule class for a state-to-state approximation
-    Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
-    dissociation-related partition functions, etc.
+    """Molecule class for a one-temperature approximation
+    Provides additional methods (compared to ``Molecule``) such as averaged vibrational energies, vibrational exponents,
+    etc.
 
     Attributes
     ----------
@@ -1110,9 +1103,8 @@ class MoleculeOneT(MoleculeQuasi):
     Notes
     -----
     Attributes whose names begin with `_current_` are not meant to be accessed directly, as doing so may lead to errors,
-    they are calculated when the `renorm_sts` method is called, and are correct only if the current flow temperature
-    is the same as the temperature which was passed to the `renorm_sts` method
-    The energy of the 0th vibrational level is set to 0, the non-zero value is stored in the vibr_zero field
+    they are calculated when the `renorm` method is called, and are correct only if the current flow temperature
+    is the same as the temperature which was passed to the `renorm` method.
     """
     def __init__(self, name, vmodel='anharmonic'):
         """Creates a new molecule
@@ -1362,6 +1354,6 @@ class MoleculeOneT(MoleculeQuasi):
             :math:`T`
         """
         if self._current_T != T:
-            return -1  # TODO
+            return (self.avg_vibr_energy_sq(T) - self.avg_vibr_energy(T) ** 2) / (constants.k * T * T * self.mass)
         else:
             return self._current_edt
\ No newline at end of file
