@@ -97,8 +97,12 @@ def diss_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule,
     float
         Non-equilibrium dissociation state-to-state rate constant
     """
-    return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
-                                          center_of_mass, vl_dependent)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i] + molecule.vibr_zero,
+                                              molecule.diss, center_of_mass, vl_dependent)
+    else:
+        return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i],
+                                              molecule.diss, center_of_mass, vl_dependent)
 
 
 def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom,
@@ -254,8 +258,8 @@ def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mol
     if isinstance(molecule, MoleculeMultiT):
         for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
             res += molecule.vibr_exp(T, T1, i) \
-                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
-                                                    center_of_mass, vl_dependent)
+                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i] + molecule.vibr_zero,
+                                                    molecule.diss_offset, center_of_mass, vl_dependent)
         return res / molecule.Z_vibr(T, T1)
     else:
         for i in range(molecule.num_vibr + 1):
@@ -265,7 +269,7 @@ def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mol
         return res / molecule.Z_vibr(T)
 
 
-def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: MoleculeQuasi,
+def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
                              atom1: Atom, atom2: Atom) -> float:
     """Calculates the averaged recombination rate constant using the Treanor-Marrone model
 
@@ -273,6 +277,8 @@ def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: Molecul
     ----------
     T : float
         the temperature of the mixture
+    T1 : float
+        the temperature of the first vibrational level of the molecule which dissociates
     model_data : 1-D array-like
         dissociation model data
     molecule : MoleculeMultiT or MoleculeOneT
@@ -288,8 +294,11 @@ def rec_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: Molecul
         Averaged recombination rate constant
     """
     if isinstance(molecule, MoleculeMultiT):
-        return raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T, T),
-                                            molecule.mass, atom1.mass, atom2.mass, molecule.diss)
+        res = 0.0
+        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+            res += raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T, T),
+                                                molecule.mass, atom1.mass,
+                                                atom2.mass, molecule.diss) * molecule.vibr_exp(T, T1, i)
     else:
         return raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T),
                                             molecule.mass, atom1.mass, atom2.mass, molecule.diss)
@@ -326,7 +335,7 @@ def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mole
     float
         Averaged recombination rate constant
     """
-    res = 0.0  # TODO - maybe this can be cleaned up?
+    res = 0.0
     if isinstance(molecule, MoleculeMultiT):
         for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
             res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
