@@ -12,7 +12,7 @@ from .particles import Molecule
 import numpy as np
 
 
-def vt_rate(T: float, idata: np.ndarray, molecule: Molecule, i: int, delta: int, rig_sphere: bool=False) -> float:
+def vt_rate_fho(T: float, idata: np.ndarray, molecule: Molecule, i: int, delta: int, rig_sphere: bool=False) -> float:
     """Calculates the VT transition rate constant using the FHO probability and VSS or rigid sphere cross-section models
     for the following process: **M(i) + P -> M(i + delta) + P**
 
@@ -39,15 +39,15 @@ def vt_rate(T: float, idata: np.ndarray, molecule: Molecule, i: int, delta: int,
 
     """
     if not rig_sphere:
-        return raw_vt_rate(T, idata[0], idata[4], idata[9], idata[10],
+        return raw_vt_rate_fho(T, idata[0], idata[4], idata[9], idata[10],
                            molecule.vibr[i], molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta)
     else:
-        return raw_vt_rate_rigid_sphere(T, idata[1], idata[0], idata[4], molecule.vibr[i], molecule.vibr[i + delta],
+        return raw_vt_rate_rigid_sphere_fho(T, idata[1], idata[0], idata[4], molecule.vibr[i], molecule.vibr[i + delta],
                                         molecule.vibr_zero, molecule.diss, i, delta)
 
 
-def vv_rate(T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule, i: int, k: int, i_delta: int,
-            rig_sphere: bool=False) -> float:
+def vv_rate_fho(T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule, i: int, k: int, i_delta: int,
+                rig_sphere: bool=False) -> float:
     """Calculates the VV transition rate constant using the FHO probability and VSS or rigid sphere cross-section models
     for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
@@ -78,17 +78,17 @@ def vv_rate(T: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecul
 
     """
     if not rig_sphere:
-        return raw_vv_rate(T, idata[0], idata[4], idata[9], idata[10],
+        return raw_vv_rate_fho(T, idata[0], idata[4], idata[9], idata[10],
                            molecule1.vibr[i], molecule1.vibr[i + i_delta],
                            molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta)
     else:
-        return raw_vv_rate_rigid_sphere(T, idata[1], idata[0], idata[4], molecule1.vibr[i], molecule1.vibr[i + i_delta],
+        return raw_vv_rate_rigid_sphere_fho(T, idata[1], idata[0], idata[4], molecule1.vibr[i], molecule1.vibr[i + i_delta],
                                         molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta)
 
 
-def raw_vt_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
-                ve_before: float, ve_after: float, molecule_vibr_zero: float,
-                molecule_diss: float, i: int, delta: int) -> float:
+def raw_vt_rate_fho(T: float, mass: float, beta: float, vssc: float, vsso: float,
+                    ve_before: float, ve_after: float, molecule_vibr_zero: float,
+                    molecule_diss: float, i: int, delta: int) -> float:
     """Calculates the VT transition rate constant using the FHO probability and VSS cross-section models
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw version*
 
@@ -127,9 +127,9 @@ def raw_vt_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
                                      molecule_vibr_zero, molecule_diss, i, delta, False)
 
 
-def raw_vt_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float,
-                             ve_before: float, ve_after: float, molecule_vibr_zero: float,
-                             molecule_diss: float, i: int, delta: int) -> float:
+def raw_vt_rate_rigid_sphere_fho(T: float, sigma: float, mass: float, beta: float,
+                                 ve_before: float, ve_after: float, molecule_vibr_zero: float,
+                                 molecule_diss: float, i: int, delta: int) -> float:
     """Calculates the VT transition rate constant using the FHO probability and rigid sphere cross-section models
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw version*
 
@@ -166,9 +166,9 @@ def raw_vt_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float,
                                                   molecule_diss, i, delta, False)
 
 
-def raw_vv_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
-                ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float,
-                i: int, k: int, i_delta: int) -> float:
+def raw_vv_rate_fho(T: float, mass: float, beta: float, vssc: float, vsso: float,
+                    ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float,
+                    i: int, k: int, i_delta: int) -> float:
     """Calculates the VV transition rate constant using the FHO probability and VSS cross-section models
     for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**, *raw version*
 
@@ -209,9 +209,9 @@ def raw_vv_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
                                      ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta, False)
 
 
-def raw_vv_rate_rigid_sphere(T: float, sigma: float, mass: float, beta: float, ve_before1: float,
-                             ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
-                             i_delta: int) -> float:
+def raw_vv_rate_rigid_sphere_fho(T: float, sigma: float, mass: float, beta: float, ve_before1: float,
+                                 ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
+                                 i_delta: int) -> float:
     """Calculates the VV transition rate constant using the FHO probability and rigid sphere cross-section models
     for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**, *raw version*
 
