@@ -10,11 +10,11 @@ from .omegaint import omega
 from scipy import constants
 from scipy.special import gamma
 from . import crosssection as cs
-from .particles import Particle, MoleculeSTS
+from .particles import Particle, Molecule
 import numpy as np
 
 
-def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, infcoll: float,
+def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infcoll: float,
                  model: str='ESA') -> float:
     """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral
 
@@ -24,7 +24,7 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, i
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule for which the rotational relaxation time is being calculated
     n : float
         the numeric density of the mixture
@@ -50,7 +50,7 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, i
     return raw_rot_rel_time(T, omega(T, 2, 2, idata, model=model, nokt=False), molecule.LJe, n, infcoll)
 
 
-def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner: Particle, n: float,
+def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: Particle, n: float,
                      rig_sphere: bool=False) -> float:
     """Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference)
@@ -61,7 +61,7 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule for which the rotational relaxation time is being calculated
     partner : Particle
         the collision partner
@@ -76,7 +76,7 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner
     float
         Rotational relaxation time
     """
-    if isinstance(partner, MoleculeSTS):
+    if isinstance(partner, Molecule):
         return raw_rot_rel_time_def_molecule_partner(T, idata[1], idata[0], idata[9], idata[10],
                                                      molecule.Z_rot(T), partner.Z_rot(T),
                                                      molecule.rot_symmetry, partner.rot_symmetry, molecule.rot_const,
@@ -88,7 +88,7 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner
                                                  molecule.num_rot, n, rig_sphere)
 
 
-def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: MoleculeSTS,
+def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
                      n: float, infcoll: float, model: str='VSS') -> float:
     """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula
 
@@ -98,7 +98,7 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: MoleculeSTS,
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule for which the rotational relaxation time is being calculated
     n : float
         the numeric density of the mixture
@@ -121,14 +121,14 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: MoleculeSTS,
                                 molecule.mass, n, infcoll, model)
 
 
-def Zr_original(T: float, molecule: MoleculeSTS, infcoll: float) -> float:
+def Zr_original(T: float, molecule: Molecule, infcoll: float) -> float:
     """Calculates the collision amount needed to reach rotational equilibrium for the rigid sphere model
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule for which the collision amount is being calculated
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
@@ -141,7 +141,7 @@ def Zr_original(T: float, molecule: MoleculeSTS, infcoll: float) -> float:
     return raw_Zr_original(T, molecule.LJe, infcoll)
 
 
-def Zr(T: float, idata: np.ndarray, molecule: MoleculeSTS, infcoll: float, model: str='VSS') -> float:
+def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models
 
     Parameters
@@ -150,7 +150,7 @@ def Zr(T: float, idata: np.ndarray, molecule: MoleculeSTS, infcoll: float, model
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule for which the collision amount is being calculated
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
@@ -170,7 +170,7 @@ def Zr(T: float, idata: np.ndarray, molecule: MoleculeSTS, infcoll: float, model
     return raw_Zr(T, idata[0], molecule.LJe, idata[6], idata[11], idata[12], molecule.mass, infcoll, model)
 
 
-def millikan_white(T: float, idata: np.ndarray, molecule: MoleculeSTS, p: float) -> float:
+def millikan_white(T: float, idata: np.ndarray, molecule: Molecule, p: float) -> float:
     """Calculates the VT relaxation time using the Millikan-White formula
 
     Parameters
@@ -179,7 +179,7 @@ def millikan_white(T: float, idata: np.ndarray, molecule: MoleculeSTS, p: float)
         the temperature of the mixture
     idata : 1-D array-like
         the array of interaction data
-    molecule : MoleculeSTS or Molecule
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
         the molecule for which the VT relaxation time is being calculated
     p : float
         the pressure (in atmospheres)
